#!/bin/bash
#####################################################
# PSXC's GetNFO v0.3 (get_nfo.sh)                   #
#                                                   #
# History:                                          #
# v0.3 - removed support for chown'ing of file.     #
#        added support for extraction of file_id.diz#
#        added chmod'ing of file_id.diz             #
#        fixed a bug re: subdir in unzip list       #
# v0.2 - added support for a better nfo extraction. #
#        added comments and how-to-use.             #
#        added some config.                         #
# v0.1 - First release.                             #
####################################################################################################
#
# How to use:
#
# This script should be run after the release is complete. Meant for d1's
# Project-ZS v0.6.x, edit the following in zsconfig.h:
#
# #define enable_complete_script  TRUE
# #define complete_script         "/bin/get_nfo.sh"
#
# Then deny *.nfo uploads in your 0day dirs. Here is an example with the
# default precheck.sh (replace 0DAY with the name of your 0day dir):
#
#  *.[nN][fF][oO])
#   if [ ! "`echo $2 | grep 0DAY`" = "" ]; then
#    echo -e ".----=== GetNFO v0.3 =====--- psxc (C)2003 --====--.\n| NFO file uploads denied.                         |\n| The .nfo will instead be extracted from the zip. |\n\`--------=======-----------------=====-------------'\n"
#    exit 2
#   fi
#  ;;
#
# copy get_nfo.sh to glftpd's bin directory (/glftpd/bin) and make sure you have the following
# in glftpd's bin directory: bash chmod chown unzip ls echo cat
#
####################################################################################################

##########
# config #
##########
# do you want the .nfo extracted to .message?
copy_to_message=1

#################
# end of config #
#################

found=0
nfocount=`ls -1 2> /dev/null | grep -i .nfo`
if [ -z "$nfocount" ] ; then
 files=`ls -1 2> /dev/null | grep -i .zip`
 for file in $files; do
  nfocount=`ls -1 2> /dev/null | grep -i .nfo`
  if [ -z "$nfocount" ] ; then 
   /bin/unzip -l $file | {
    while read Length Date Time Name; do
     if [ ! "`echo $Name | grep -i .nfo`" = "" ]; then
      if [ ! $found = 1 ]; then
       found=1
       plain=`echo $Name | /bin/sed "s|/| |g"`
       for plain_name in $plain; do
        New_Name=$plain_name
       done
       /bin/unzip -Cqqp $file $Name > $New_Name
       if [ ! "$copy_to_message" = "0" ]; then
        echo "" >> .message
        echo "content of $New_Name:" >> .message
        echo "" >> .message
        cat $New_Name >> .message
       fi
       /bin/chmod 644 $New_Name
       if [ ! -e file_id.diz ]; then
        /bin/unzip -Cqqp $file file_id.diz > file_id.diz
       fi
       if [ -e file_id.diz ]; then
        /bin/chmod 644 file_id.diz
       fi
      fi
     fi
    done
   }
  fi
 done
fi
exit 0

